@@ -1,4 +1,5 @@
 # sage_setup: distribution = sagemath-repl
+# sage.doctest: needs sage.all
 """
 Classes involved in doctesting
 
@@ -282,10 +283,14 @@ def skipfile(filename, tested_optional_tags=False, *,
         sage: skipfile(filename, True)
         False
     """
+    if filename.endswith('__main__.py'):
+        if log:
+            log(f"Skipping '{filename}' because it is a __main__.py file")
+        return True
     if filename.endswith('.rst.txt'):
         ext = '.rst.txt'
     else:
-        base, ext = os.path.splitext(filename)
+        _ , ext = os.path.splitext(filename)
     # .rst.txt appear in the installed documentation in subdirectories named "_sources"
     if ext not in ('.py', '.pyx', '.pxd', '.pxi', '.sage', '.spyx', '.rst', '.tex', '.rst.txt'):
         if log:
@@ -338,7 +343,7 @@ def skipfile(filename, tested_optional_tags=False, *,
     return False
 
 
-class Logger():
+class Logger:
     r"""
     File-like object which implements writing to multiple files at
     once.
@@ -492,7 +497,7 @@ class DocTestController(SageObject):
                         if pkg.name in options.hide:
                             continue
                         # Skip features for which we have a more specific runtime feature test.
-                        if pkg.name in ['bliss', 'coxeter3', 'mcqd', 'meataxe', 'sirocco', 'tdlib']:
+                        if pkg.name in ['bliss', 'coxeter3', 'giac', 'mcqd', 'meataxe', 'sirocco', 'tdlib', 'latte_int']:
                             continue
                         if pkg.is_installed() and pkg.installed_version == pkg.remote_version:
                             options.optional.add(pkg.name)
@@ -588,36 +593,38 @@ class DocTestController(SageObject):
 
     def _init_warn_long(self):
         """
-        Pick a suitable default for the ``--warn-long`` option if not specified.
+        Pick a suitable default for the ``--warn-long`` option if not
+        specified.
 
         It is desirable to have all tests (even ``# long`` ones)
         finish in less than about 5 seconds. Longer tests typically
         don't add coverage, they just make testing slow.
 
-        The default used here is 60 seconds on a modern computer. It
-        should eventually be lowered to 5 seconds, but its best to
-        boil the frog slowly.
+        The default used here is 5 seconds, unless `--long` was used,
+        in which case it is 30 seconds.
 
-        The stored timings are used to adjust this limit according to
-        the machine running the tests.
+        TESTS:
 
-        EXAMPLES::
+        Ensure that the user's command-line options are not changed::
 
-            sage: from sage.doctest.control import DocTestDefaults, DocTestController
+            sage: from sage.doctest.control import (DocTestDefaults,
+            ....:                                   DocTestController)
             sage: DC = DocTestController(DocTestDefaults(), [])
             sage: DC.options.warn_long = 5.0
             sage: DC._init_warn_long()
-            sage: DC.options.warn_long    # existing command-line options are not changed
+            sage: DC.options.warn_long
             5.00000000000000
         """
         # default is -1.0
         if self.options.warn_long >= 0:     # Specified on the command line
             return
-        try:
-            self.options.warn_long = 60.0 * self.second_on_modern_computer()
-        except RuntimeError as err:
-            if not sage.doctest.DOCTEST_MODE:
-                print(err)   # No usable timing information
+
+        # The developer's guide says that even a "long time" test
+        # should ideally complete in under five seconds, so we're
+        # being rather generous here.
+        self.options.warn_long = 5.0
+        if self.options.long:
+            self.options.warn_long = 30.0
 
     def second_on_modern_computer(self):
         """
@@ -637,6 +644,9 @@ class DocTestController(SageObject):
             sage: DC = DocTestController(DocTestDefaults(), [])
             sage: DC.second_on_modern_computer()   # not tested
         """
+        from sage.misc.superseded import deprecation
+        deprecation(32981, "this method is no longer used by the sage library and will eventually be removed")
+
         if len(self.stats) == 0:
             raise RuntimeError('no stored timings available')
         success = []
@@ -674,10 +684,10 @@ class DocTestController(SageObject):
 
             sage: from sage.doctest.control import DocTestDefaults, DocTestController
             sage: DC = DocTestController(DocTestDefaults(), [])
-            sage: 'BipartiteGraph' in DC.load_environment().__dict__
+            sage: 'BipartiteGraph' in DC.load_environment().__dict__                    # needs sage.graphs
             True
             sage: DC = DocTestController(DocTestDefaults(environment='sage.doctest.all'), [])
-            sage: 'BipartiteGraph' in  DC.load_environment().__dict__
+            sage: 'BipartiteGraph' in  DC.load_environment().__dict__                   # needs sage.graphs
             False
             sage: 'run_doctests' in DC.load_environment().__dict__
             True
@@ -985,7 +995,7 @@ class DocTestController(SageObject):
             sage: DC = DocTestController(DD, [dirname])
             sage: DC.expand_files_into_sources()
             sage: len(DC.sources)
-            16
+            15
             sage: DC.sources[0].options.optional
             True
 
@@ -1097,7 +1107,6 @@ class DocTestController(SageObject):
             sage.doctest.control
             sage.doctest.check_tolerance
             sage.doctest.all
-            sage.doctest.__main__
             sage.doctest
         """
         if self.options.nthreads > 1 and len(self.sources) > self.options.nthreads:
@@ -1152,7 +1161,7 @@ class DocTestController(SageObject):
             sage: DC.run_doctests()
             Doctesting 1 file.
             sage -t .../sage/rings/homset.py
-                [... tests, ... s]
+                [... tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1229,7 +1238,7 @@ class DocTestController(SageObject):
             Running doctests with ID ...
             Doctesting 1 file.
             sage -t .../rings/all.py
-                [... tests, ... s]
+                [... tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1433,7 +1442,7 @@ class DocTestController(SageObject):
             Running doctests with ID ...
             Doctesting 1 file.
             sage -t .../sage/sets/non_negative_integers.py
-                [... tests, ... s]
+                [... tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1457,7 +1466,7 @@ class DocTestController(SageObject):
             Features to be detected: ...
             Doctesting 1 file.
             sage -t ....py
-                [0 tests, ... s]
+                [0 tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1483,7 +1492,7 @@ class DocTestController(SageObject):
             Features to be detected: ...
             Doctesting 1 file.
             sage -t ....py
-                [4 tests, ... s]
+                [4 tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1501,7 +1510,7 @@ class DocTestController(SageObject):
             Features to be detected: ...
             Doctesting 1 file.
             sage -t ....py
-                [4 tests, ... s]
+                [4 tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1519,7 +1528,7 @@ class DocTestController(SageObject):
             Features to be detected: ...
             Doctesting 1 file.
             sage -t ....py
-                [4 tests, ... s]
+                [4 tests, ...s wall]
             ----------------------------------------------------------------------
             All tests passed!
             ----------------------------------------------------------------------
@@ -1627,7 +1636,7 @@ def run_doctests(module, options=None):
         Running doctests with ID ...
         Doctesting 1 file.
         sage -t .../sage/rings/all.py
-            [... tests, ... s]
+            [... tests, ...s wall]
         ----------------------------------------------------------------------
         All tests passed!
         ----------------------------------------------------------------------
